@@ -3,7 +3,7 @@ package Plack::Middleware::ServerStatus::Lite;
 use strict;
 use warnings;
 use parent qw(Plack::Middleware);
-use Plack::Util::Accessor qw(scoreboard path allow counter_file);
+use Plack::Util::Accessor qw(scoreboard path allow counter_file skip_ps_command);
 use Plack::Util;
 use Parallel::Scoreboard;
 use Net::CIDR::Lite;
@@ -12,7 +12,7 @@ use JSON;
 use Fcntl qw(:DEFAULT :flock);
 use IO::Handle;
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 sub prepare_app {
     my $self = shift;
@@ -126,14 +126,20 @@ sub _handle_server_status {
         my $idle = 0;
         my $busy = 0;
 
-        my $parent_pid = getppid;
-        my $ps = `LC_ALL=C command ps -e -o ppid,pid`;
-        $ps =~ s/^\s+//mg;
         my @all_workers;
-        for my $line ( split /\n/, $ps ) {
-            next if $line =~ m/^\D/;
-            my ($ppid, $pid) = split /\s+/, $line, 2;
-            push @all_workers, $pid if $ppid == $parent_pid;
+        if ( ! $self->skip_ps_command ) {
+            my $parent_pid = getppid;
+            my $ps = `LC_ALL=C command ps -e -o ppid,pid`;
+            $ps =~ s/^\s+//mg;
+        
+            for my $line ( split /\n/, $ps ) {
+                next if $line =~ m/^\D/;
+                my ($ppid, $pid) = split /\s+/, $line, 2;
+                push @all_workers, $pid if $ppid == $parent_pid;
+            }
+        }
+        else {
+            @all_workers = keys %$stats;
         }
 
         my @raw_stats;
@@ -322,6 +328,16 @@ Scoreboard directory, Middleware::ServerStatus::Lite stores processes activity i
 
 Enable Total Access counter
 
+
+=item skip_ps_command
+
+  skip_ps_command => 1 or 0
+
+ServerStatus::Lite executes `ps command` to find all worker processes. But in some systems 
+that does not mount "/proc" can not find any processes. 
+IF 'skip_ps_command' is true, ServerStatus::Lite does not `ps`, and checks only processes that 
+already did process requests.
+
 =back
 
 =head1 TOTAL BYTES
